==> brmo-stufbg204-1.6.1-sources.jar: nl/egem/stuf/sector/bg/_0204/NNPVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Niet natuurlijk persoon binnen vraagbericht
 * 
 * <p>Java class for NNP-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NNP-vraag">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund">
 *       &lt;sequence>
 *         &lt;element name="NNPADRCOR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" minOccurs="0"/>
 *         &lt;element name="NNPADRVBL" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" minOccurs="0"/>
 *         &lt;element name="NNPNNPHFD" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="NNPNNPNVN" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NNP-vraag", propOrder = {
    "nnpadrcor",
    "nnpadrvbl",
    "nnpnnphfd",
    "nnpnnpnvn"
})
public class NNPVraag
    extends NNPFund
{

    @XmlElementRef(name = "NNPADRCOR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelFund> nnpadrcor;
    @XmlElementRef(name = "NNPADRVBL", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelFund> nnpadrvbl;
    @XmlElementRef(name = "NNPNNPHFD", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NNPVraag.NNPNNPHFD> nnpnnphfd;
    @XmlElementRef(name = "NNPNNPNVN", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NNPVraag.NNPNNPNVN> nnpnnpnvn;

    /**
     * Gets the value of the nnpadrcor property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public JAXBElement<ADRRelFund> getNNPADRCOR() {
        return nnpadrcor;
    }

    /**
     * Sets the value of the nnpadrcor property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public void setNNPADRCOR(JAXBElement<ADRRelFund> value) {
        this.nnpadrcor = value;
    }

    /**
     * Gets the value of the nnpadrvbl property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public JAXBElement<ADRRelFund> getNNPADRVBL() {
        return nnpadrvbl;
    }

    /**
     * Sets the value of the nnpadrvbl property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public void setNNPADRVBL(JAXBElement<ADRRelFund> value) {
        this.nnpadrvbl = value;
    }

    /**
     * Gets the value of the nnpnnphfd property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPHFD }{@code >}
     *     
     */
    public JAXBElement<NNPVraag.NNPNNPHFD> getNNPNNPHFD() {
        return nnpnnphfd;
    }

    /**
     * Sets the value of the nnpnnphfd property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPHFD }{@code >}
     *     
     */
    public void setNNPNNPHFD(JAXBElement<NNPVraag.NNPNNPHFD> value) {
        this.nnpnnphfd = value;
    }

    /**
     * Gets the value of the nnpnnpnvn property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPNVN }{@code >}
     *     
     */
    public JAXBElement<NNPVraag.NNPNNPNVN> getNNPNNPNVN() {
        return nnpnnpnvn;
    }

    /**
     * Sets the value of the nnpnnpnvn property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPNVN }{@code >}
     *     
     */
    public void setNNPNNPNVN(JAXBElement<NNPVraag.NNPNNPNVN> value) {
        this.nnpnnpnvn = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPHFD
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPNVN
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/NNPVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Niet natuurlijk persoon binnen vraagbericht
 * 
 * <p>Java class for NNP-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NNP-vraag"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="NNPADRCOR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" minOccurs="0"/&gt;
 *         &lt;element name="NNPADRVBL" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" minOccurs="0"/&gt;
 *         &lt;element name="NNPNNPHFD" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="NNPNNPNVN" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NNP-vraag", propOrder = {
    "nnpadrcor",
    "nnpadrvbl",
    "nnpnnphfd",
    "nnpnnpnvn"
})
public class NNPVraag
    extends NNPFund
{

    @XmlElementRef(name = "NNPADRCOR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelFund> nnpadrcor;
    @XmlElementRef(name = "NNPADRVBL", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelFund> nnpadrvbl;
    @XmlElementRef(name = "NNPNNPHFD", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NNPVraag.NNPNNPHFD> nnpnnphfd;
    @XmlElementRef(name = "NNPNNPNVN", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NNPVraag.NNPNNPNVN> nnpnnpnvn;

    /**
     * Gets the value of the nnpadrcor property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public JAXBElement<ADRRelFund> getNNPADRCOR() {
        return nnpadrcor;
    }

    /**
     * Sets the value of the nnpadrcor property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public void setNNPADRCOR(JAXBElement<ADRRelFund> value) {
        this.nnpadrcor = value;
    }

    /**
     * Gets the value of the nnpadrvbl property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public JAXBElement<ADRRelFund> getNNPADRVBL() {
        return nnpadrvbl;
    }

    /**
     * Sets the value of the nnpadrvbl property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelFund }{@code >}
     *     
     */
    public void setNNPADRVBL(JAXBElement<ADRRelFund> value) {
        this.nnpadrvbl = value;
    }

    /**
     * Gets the value of the nnpnnphfd property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPHFD }{@code >}
     *     
     */
    public JAXBElement<NNPVraag.NNPNNPHFD> getNNPNNPHFD() {
        return nnpnnphfd;
    }

    /**
     * Sets the value of the nnpnnphfd property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPHFD }{@code >}
     *     
     */
    public void setNNPNNPHFD(JAXBElement<NNPVraag.NNPNNPHFD> value) {
        this.nnpnnphfd = value;
    }

    /**
     * Gets the value of the nnpnnpnvn property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPNVN }{@code >}
     *     
     */
    public JAXBElement<NNPVraag.NNPNNPNVN> getNNPNNPNVN() {
        return nnpnnpnvn;
    }

    /**
     * Sets the value of the nnpnnpnvn property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NNPVraag.NNPNNPNVN }{@code >}
     *     
     */
    public void setNNPNNPNVN(JAXBElement<NNPVraag.NNPNNPNVN> value) {
        this.nnpnnpnvn = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPHFD
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPNVN
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

    }

}
